==> netease_roomkit_interface-0.0.1-rc.2.tar.gz: lib/src/types/server_configs.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:json_annotation/json_annotation.dart';

part 'server_configs.g.dart';

///
/// 服务器配置
///
@JsonSerializable(
  includeIfNull: false,
  explicitToJson: true,
)
class NEServerConfig {
  @JsonKey(name: "roomkit")
  NERoomKitServerConfig? roomKitServerConfig;

  @JsonKey(name: "im")
  NEIMServerConfig? imServerConfig;

  @JsonKey(name: "rtc")
  NERtcServerConfig? rtcServerConfig;

  @JsonKey(name: "whiteboard")
  NEWhiteboardServerConfig? whiteboardServerConfig;

  NEServerConfig();

  factory NEServerConfig.fromJson(Map map) {
    return _$NEServerConfigFromJson(map.cast());
  }

  Map toJson() => _$NEServerConfigToJson(this);
}

///
/// IM 服务器配置项
///
@JsonSerializable(
  includeIfNull: false,
)
class NEIMServerConfig {
  ///
  /// 连接云信服务器加密数据通道的公钥参数1 rsaModulus
  ///
  @JsonKey(name: "module")
  String? module;

  ///
  /// 连接云信服务器加密数据通道的公钥的版本号（默认0）
  ///
  @JsonKey(name: "version", defaultValue: 0)
  int version = 0;

  ///
  /// IM LBS服务器地址，通过它获取IM link 地址信息; 填http/https地址
  ///
  @JsonKey(name: "lbs")
  String? lbs;

  ///
  /// 备用IM LBS服务器地址，通过它获取IM link 地址信息
  /// 填http/https地址
  ///
  ///
  List<String>? lbsBackup;

  ///
  /// IM 默认的link服务器地址，当IM LBS不可用时先连接该地址
  /// 填"IP/Host:PORT"
  ///
  @JsonKey(name: "link")
  String? link;

  ///
  /// IM 默认的link服务器地址不可用时，连接这些地址
  /// 填"IP/Host:PORT"
  ///
  List<String>? linkBackup;

  ///
  /// NOS上传LBS服务器地址
  /// 填http/https地址
  ///
  @JsonKey(name: "nos_lbs")
  String? nosLbs;

  ///
  /// NOS上传默认的link服务器地址，当NOS LBS不可用时先连接该地址
  /// 填http/https地址
  ///
  @JsonKey(name: "nos_uploader")
  String? nosUploader;

  ///
  /// NOS上传服务器主机地址（仅nosSupportHttps=true时有效，用作https上传时的域名校验及http header host字段填充）
  /// 填host地址
  ///
  @JsonKey(name: "nos_uploader_host")
  String? nosUploaderHost;

  ///
  /// NOS上传是否需要支持https。SDK 3.2版本后默认支持https，同时需要配置 nosUpload!
  ///
  @JsonKey(name: "https_enabled")
  bool? httpsEnabled;

  ///
  /// [4.6.0版本新增] NOS下载地址拼接模板，用于拼接最终得到的下载地址。
  /// 默认是 {bucket}.nosdn.127.net/{object}，SDK 上传资源后生成的下载地址为 https://bucket.nosdn.127.net/object
  ///
  @JsonKey(name: "nos_downloader")
  String? nosDownloader;

  ///
  /// NOS下载地址的host，用于拼接最终获得的文件URL地址，也支持该host替换成下载加速域名/地址 nosAccess.
  /// 填host地址, 默认是 nos.netease.com
  ///
  @JsonKey(name: "nos_accelerate_host")
  String? nosAccelerateHost;

  ///
  /// NOS下载加速域名/地址，用于替换NOS下载url中的 nosDownload。
  /// 提供两种方式：
  /// 1) [4.4.0+开始支持]模板方式：填写云信规定的两种模板：{bucket}.nosdn.127.net/{object} 或者 nosdn.127.net/{bucket}/{object}，其中 {bucket} 和 {object} 作为标识符，必须填写。域名部分可以替换为您申请的加速域名。
  /// 2) 所有版本支持非模板方式：填写用于加速的 http/https地址，例如：http://111.222.111.22:9090
  ///
  @JsonKey(name: "nos_accelerate")
  String? nosAccelerate;

  ///
  /// 是否优先使用Cdn域名进行NOS下载
  ///
  @JsonKey(name: "nos_cdn_enable")
  bool? nosCdnEnable;

  @JsonKey(name: "nos_accelerate_host_list")
  List<String>? nosAccelerateHostList;

  ///
  /// 云信运行时异常统计服务器地址
  ///
  @JsonKey(name: "nt_server")
  String? ntServer;

  ///
  /// 云信数据统计服务器地址
  ///
  @JsonKey(name: "bd_server")
  String? bdServer;

  ///
  /// 是否为专属集群{1(是), 0(否)}
  ///
  @JsonKey(name: "dedicated_cluste_flag", defaultValue: 0)
  int dedicatedClusteFlag = 0;

  ///
  /// "交换密钥"协议加密算法 {1(RSA),2(SM2)}, def:1(RSA) 非对称加密
  ///
  @JsonKey(
    name: "nego_key_neca",
    fromJson: _$AsymmetricTypeFromValue,
    toJson: _$AsymmetricTypeToValue,
  )
  AsymmetricType? negoKeyNeca;

  ///
  /// "交换密钥"协议加密算法密钥版本 version 自定义时则必填
  ///
  @JsonKey(name: "nego_key_enca_key_version", defaultValue: 0)
  int negoKeyEncaKeyVersion = 0;

  ///
  /// "交换密钥"协议加密算法密钥 part A 自定义时则必填 BigNumHex string 不含0x RSA: module, SM2: X
  ///
  @JsonKey(name: "nego_key_enca_key_parta")
  String? negoKeyEncaKeyParta;

  ///
  /// "交换密钥"协议加密算法密钥 part B 自定义时则必填 BigNumHex string 不含0x RSA: EXP, SM2: Y
  ///
  @JsonKey(name: "nego_key_enca_key_partb")
  String? negoKeyEncaKeyPartb;

  ///
  /// 通信加密算法 {1(RC4), 2(AES128), 4(SM4)}
  /// 默认: 1(RC4) 对称加密
  ///
  @JsonKey(
    name: "comm_enca",
    fromJson: _$SymmetryTypeFromValue,
    toJson: _$SymmetryTypeToValue,
  )
  SymmetryType? commEnca;

  ///
  /// ipv6的缺省连接地址
  ///
  @JsonKey(name: "link_ipv6")
  String? linkIpv6;

  ///
  /// IP协议版本{0(IPV4), 1(IPV6), 2(Auto, SDK测试后自行选择, 存在性能损耗)}。
  /// 默认: 0(IPV4) 非对称加密
  ///
  @JsonKey(
    name: "ip_protocol_version",
    fromJson: _$IPVersionFromValue,
    toJson: _$IPVersionToValue,
  )
  IPVersion? ipProtocolVersion;

  ///
  /// 探测ipv4地址类型使用的url, IPProtVersion == 2 时生效
  ///
  @JsonKey(name: "probe_ipv4_url")
  String? probeIpv4Url;

  ///
  /// 探测ipv6地址类型使用的url, IPProtVersion == 2 时生效
  ///
  @JsonKey(name: "probe_ipv6_url")
  String? probeIpv6Url;

  ///
  /// 握手协议选择字段
  ///
  @JsonKey(
    name: "hand_shake_type",
    fromJson: _$HandshakeTypeFromValue,
    toJson: _$HandshakeTypeToValue,
  )
  HandshakeType? handshakeType;

  NEIMServerConfig();

  factory NEIMServerConfig.fromJson(Map map) {
    return _$IMServerConfigFromJson(map.cast());
  }

  Map toJson() => _$IMServerConfigToJson(this);
}

class AsymmetricType {
  final int value;

  const AsymmetricType._(this.value);

  static const rsa = AsymmetricType._(1);
  static const sm2 = AsymmetricType._(2);
  static const rsa_oaep_1 = AsymmetricType._(4);
  static const rsa_oaep_256 = AsymmetricType._(8);

  static const values = [rsa, sm2, rsa_oaep_1, rsa_oaep_256];
}

AsymmetricType? _$AsymmetricTypeFromValue(int? value) {
  for (var item in AsymmetricType.values) {
    if (item.value == value) {
      return item;
    }
  }
  return null;
}

int? _$AsymmetricTypeToValue(AsymmetricType? type) => type?.value;

class SymmetryType {
  final int value;

  const SymmetryType._(this.value);

  static const rc4 = SymmetryType._(1);
  static const aes = SymmetryType._(2);
  static const sm4 = SymmetryType._(4);

  static const values = [rc4, aes, sm4];
}

SymmetryType? _$SymmetryTypeFromValue(int? value) {
  for (var item in SymmetryType.values) {
    if (item.value == value) {
      return item;
    }
  }
  return null;
}

int? _$SymmetryTypeToValue(SymmetryType? type) => type?.value;

class IPVersion {
  final int value;

  const IPVersion._(this.value);

  static const ipv4 = IPVersion._(0);
  static const ipv6 = IPVersion._(1);
  static const any = IPVersion._(2);

  static const values = [ipv4, ipv6, any];
}

int? _$IPVersionToValue(IPVersion? version) => version?.value;

IPVersion? _$IPVersionFromValue(int? value) {
  for (var item in IPVersion.values) {
    if (item.value == value) {
      return item;
    }
  }
  return null;
}

class HandshakeType {
  final int value;

  const HandshakeType._(this.value);

  static const v0 = HandshakeType._(0);
  static const v1 = HandshakeType._(1);

  static const values = [v0, v1];
}

int? _$HandshakeTypeToValue(HandshakeType? type) => type?.value;

HandshakeType? _$HandshakeTypeFromValue(int? value) {
  for (var item in HandshakeType.values) {
    if (item.value == value) {
      return item;
    }
  }
  return null;
}

///
/// RTC 服务器配置
///
@JsonSerializable(
  includeIfNull: false,
)
class NERtcServerConfig {
  String? channelServer;
  String? statisticsServer;
  String? roomServer;
  String? compatServer;
  String? nosLbsServer;
  String? nosUploadSever;
  String? nosTokenServer;
  String? cloudProxyServer;
  String? webSocketProxyServer;
  String? quicProxyServer;
  String? mediaProxyServer;
  @JsonKey(defaultValue: false)
  bool useIPv6 = false;

  NERtcServerConfig();

  factory NERtcServerConfig.fromJson(Map map) {
    return _$RtcServerConfigFromJson(map.cast());
  }

  Map toJson() => _$RtcServerConfigToJson(this);
}

///
/// RoomKit 服务器配置
///
@JsonSerializable(
  includeIfNull: false,
)
class NERoomKitServerConfig {
  String? roomServer;

  NERoomKitServerConfig();

  factory NERoomKitServerConfig.fromJson(Map map) {
    return _$RoomKitServerConfigFromJson(map.cast());
  }

  Map toJson() => _$RoomKitServerConfigToJson(this);
}

///
/// G2 白板 服务器配置
///
@JsonSerializable(
  includeIfNull: false,
)
class NEWhiteboardServerConfig {
  String? webServer;
  String? roomServer;
  String? sdkLogNosServer;
  String? dataReportServer;
  String? directNosServer;
  String? mediaUploadServer;
  String? docTransServer;
  String? fontDownloadServer;

  NEWhiteboardServerConfig();

  factory NEWhiteboardServerConfig.fromJson(Map map) {
    return _$WhiteboardServerConfigFromJson(map.cast());
  }

  Map toJson() => _$WhiteboardServerConfigToJson(this);
}

==> netease_roomkit_interface-1.26.0.tar.gz: lib/src/types/server_configs.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:json_annotation/json_annotation.dart';

part 'server_configs.g.dart';

///
/// 服务器配置
///
@JsonSerializable(
  includeIfNull: false,
  explicitToJson: true,
)
class NEServerConfig {
  @JsonKey(name: "roomkit")
  NERoomKitServerConfig? roomKitServerConfig;

  @JsonKey(name: "im")
  NEIMServerConfig? imServerConfig;

  @JsonKey(name: "rtc")
  NERtcServerConfig? rtcServerConfig;

  @JsonKey(name: "whiteboard")
  NEWhiteboardServerConfig? whiteboardServerConfig;

  NEServerConfig();

  factory NEServerConfig.fromJson(Map map) {
    return _$NEServerConfigFromJson(map.cast());
  }

  Map toJson() => _$NEServerConfigToJson(this);
}

///
/// IM 服务器配置项
///
@JsonSerializable(
  includeIfNull: false,
)
class NEIMServerConfig {
  ///
  /// 连接云信服务器加密数据通道的公钥参数1 rsaModulus
  ///
  @JsonKey(name: "module")
  String? module;

  ///
  /// 连接云信服务器加密数据通道的公钥的版本号（默认0）
  ///
  @JsonKey(name: "version", defaultValue: 0)
  int version = 0;

  ///
  /// IM LBS服务器地址，通过它获取IM link 地址信息; 填http/https地址
  ///
  @JsonKey(name: "lbs")
  String? lbs;

  ///
  /// 备用IM LBS服务器地址，通过它获取IM link 地址信息
  /// 填http/https地址
  ///
  ///
  List<String>? lbsBackup;

  ///
  /// IM 默认的link服务器地址，当IM LBS不可用时先连接该地址
  /// 填"IP/Host:PORT"
  ///
  @JsonKey(name: "link")
  String? link;

  ///
  /// IM 默认的link服务器地址不可用时，连接这些地址
  /// 填"IP/Host:PORT"
  ///
  List<String>? linkBackup;

  ///
  /// NOS上传LBS服务器地址
  /// 填http/https地址
  ///
  @JsonKey(name: "nos_lbs")
  String? nosLbs;

  ///
  /// NOS上传默认的link服务器地址，当NOS LBS不可用时先连接该地址
  /// 填http/https地址
  ///
  @JsonKey(name: "nos_uploader")
  String? nosUploader;

  ///
  /// NOS上传服务器主机地址（仅nosSupportHttps=true时有效，用作https上传时的域名校验及http header host字段填充）
  /// 填host地址
  ///
  @JsonKey(name: "nos_uploader_host")
  String? nosUploaderHost;

  ///
  /// NOS上传是否需要支持https。SDK 3.2版本后默认支持https，同时需要配置 nosUpload!
  ///
  @JsonKey(name: "https_enabled")
  bool? httpsEnabled;

  ///
  /// [4.6.0版本新增] NOS下载地址拼接模板，用于拼接最终得到的下载地址。
  /// 默认是 {bucket}.nosdn.127.net/{object}，SDK 上传资源后生成的下载地址为 https://bucket.nosdn.127.net/object
  ///
  @JsonKey(name: "nos_downloader")
  String? nosDownloader;

  ///
  /// NOS下载地址的host，用于拼接最终获得的文件URL地址，也支持该host替换成下载加速域名/地址 nosAccess.
  /// 填host地址, 默认是 nos.netease.com
  ///
  @JsonKey(name: "nos_accelerate_host")
  String? nosAccelerateHost;

  ///
  /// NOS下载加速域名/地址，用于替换NOS下载url中的 nosDownload。
  /// 提供两种方式：
  /// 1) [4.4.0+开始支持]模板方式：填写云信规定的两种模板：{bucket}.nosdn.127.net/{object} 或者 nosdn.127.net/{bucket}/{object}，其中 {bucket} 和 {object} 作为标识符，必须填写。域名部分可以替换为您申请的加速域名。
  /// 2) 所有版本支持非模板方式：填写用于加速的 http/https地址，例如：http://111.222.111.22:9090
  ///
  @JsonKey(name: "nos_accelerate")
  String? nosAccelerate;

  ///
  /// 是否优先使用Cdn域名进行NOS下载
  ///
  @JsonKey(name: "nos_cdn_enable")
  bool? nosCdnEnable;

  @JsonKey(name: "nos_accelerate_host_list")
  List<String>? nosAccelerateHostList;

  ///
  /// 云信运行时异常统计服务器地址
  ///
  @JsonKey(name: "nt_server")
  String? ntServer;

  ///
  /// 云信数据统计服务器地址
  ///
  @JsonKey(name: "bd_server")
  String? bdServer;

  ///
  /// 是否为专属集群{1(是), 0(否)}
  ///
  @JsonKey(name: "dedicated_cluste_flag", defaultValue: 0)
  int dedicatedClusteFlag = 0;

  ///
  /// "交换密钥"协议加密算法 {1(RSA),2(SM2)}, def:1(RSA) 非对称加密
  ///
  @JsonKey(
    name: "nego_key_neca",
    fromJson: _$AsymmetricTypeFromValue,
    toJson: _$AsymmetricTypeToValue,
  )
  AsymmetricType? negoKeyNeca;

  ///
  /// "交换密钥"协议加密算法密钥版本 version 自定义时则必填
  ///
  @JsonKey(name: "nego_key_enca_key_version", defaultValue: 0)
  int negoKeyEncaKeyVersion = 0;

  ///
  /// "交换密钥"协议加密算法密钥 part A 自定义时则必填 BigNumHex string 不含0x RSA: module, SM2: X
  ///
  @JsonKey(name: "nego_key_enca_key_parta")
  String? negoKeyEncaKeyParta;

  ///
  /// "交换密钥"协议加密算法密钥 part B 自定义时则必填 BigNumHex string 不含0x RSA: EXP, SM2: Y
  ///
  @JsonKey(name: "nego_key_enca_key_partb")
  String? negoKeyEncaKeyPartb;

  ///
  /// 通信加密算法 {1(RC4), 2(AES128), 4(SM4)}
  /// 默认: 1(RC4) 对称加密
  ///
  @JsonKey(
    name: "comm_enca",
    fromJson: _$SymmetryTypeFromValue,
    toJson: _$SymmetryTypeToValue,
  )
  SymmetryType? commEnca;

  ///
  /// ipv6的缺省连接地址
  ///
  @JsonKey(name: "link_ipv6")
  String? linkIpv6;

  ///
  /// IP协议版本{0(IPV4), 1(IPV6), 2(Auto, SDK测试后自行选择, 存在性能损耗)}。
  /// 默认: 0(IPV4) 非对称加密
  ///
  @JsonKey(
    name: "ip_protocol_version",
    fromJson: _$IPVersionFromValue,
    toJson: _$IPVersionToValue,
  )
  IPVersion? ipProtocolVersion;

  ///
  /// 探测ipv4地址类型使用的url, IPProtVersion == 2 时生效
  ///
  @JsonKey(name: "probe_ipv4_url")
  String? probeIpv4Url;

  ///
  /// 探测ipv6地址类型使用的url, IPProtVersion == 2 时生效
  ///
  @JsonKey(name: "probe_ipv6_url")
  String? probeIpv6Url;

  ///
  /// 握手协议选择字段
  ///
  @JsonKey(
    name: "hand_shake_type",
    fromJson: _$HandshakeTypeFromValue,
    toJson: _$HandshakeTypeToValue,
  )
  HandshakeType? handshakeType;

  NEIMServerConfig();

  factory NEIMServerConfig.fromJson(Map map) {
    return _$NEIMServerConfigFromJson(map.cast());
  }

  Map toJson() => _$NEIMServerConfigToJson(this);
}

class AsymmetricType {
  final int value;

  const AsymmetricType._(this.value);

  static const rsa = AsymmetricType._(1);
  static const sm2 = AsymmetricType._(2);
  static const rsa_oaep_1 = AsymmetricType._(4);
  static const rsa_oaep_256 = AsymmetricType._(8);

  static const values = [rsa, sm2, rsa_oaep_1, rsa_oaep_256];
}

AsymmetricType? _$AsymmetricTypeFromValue(int? value) {
  for (var item in AsymmetricType.values) {
    if (item.value == value) {
      return item;
    }
  }
  return null;
}

int? _$AsymmetricTypeToValue(AsymmetricType? type) => type?.value;

class SymmetryType {
  final int value;

  const SymmetryType._(this.value);

  static const rc4 = SymmetryType._(1);
  static const aes = SymmetryType._(2);
  static const sm4 = SymmetryType._(4);

  static const values = [rc4, aes, sm4];
}

SymmetryType? _$SymmetryTypeFromValue(int? value) {
  for (var item in SymmetryType.values) {
    if (item.value == value) {
      return item;
    }
  }
  return null;
}

int? _$SymmetryTypeToValue(SymmetryType? type) => type?.value;

class IPVersion {
  final int value;

  const IPVersion._(this.value);

  static const ipv4 = IPVersion._(0);
  static const ipv6 = IPVersion._(1);
  static const any = IPVersion._(2);

  static const values = [ipv4, ipv6, any];
}

int? _$IPVersionToValue(IPVersion? version) => version?.value;

IPVersion? _$IPVersionFromValue(int? value) {
  for (var item in IPVersion.values) {
    if (item.value == value) {
      return item;
    }
  }
  return null;
}

class HandshakeType {
  final int value;

  const HandshakeType._(this.value);

  static const v0 = HandshakeType._(0);
  static const v1 = HandshakeType._(1);

  static const values = [v0, v1];
}

int? _$HandshakeTypeToValue(HandshakeType? type) => type?.value;

HandshakeType? _$HandshakeTypeFromValue(int? value) {
  for (var item in HandshakeType.values) {
    if (item.value == value) {
      return item;
    }
  }
  return null;
}

///
/// RTC 服务器配置
///
@JsonSerializable(
  includeIfNull: false,
)
class NERtcServerConfig {
  String? channelServer;
  String? statisticsServer;
  String? statisticsDispatchServer;
  String? statisticsBackupServer;
  String? roomServer;
  String? compatServer;
  String? nosLbsServer;
  String? nosUploadSever;
  String? nosTokenServer;
  String? sdkConfigServer;
  String? cloudProxyServer;
  String? webSocketProxyServer;
  String? quicProxyServer;
  String? mediaProxyServer;
  @JsonKey(defaultValue: false)
  bool useIPv6 = false;

  NERtcServerConfig();

  factory NERtcServerConfig.fromJson(Map map) {
    return _$NERtcServerConfigFromJson(map.cast());
  }

  Map toJson() => _$NERtcServerConfigToJson(this);
}

///
/// RoomKit 服务器配置
///
@JsonSerializable(
  includeIfNull: false,
)
class NERoomKitServerConfig {
  String? roomServer;

  NERoomKitServerConfig();

  factory NERoomKitServerConfig.fromJson(Map map) {
    return _$NERoomKitServerConfigFromJson(map.cast());
  }

  Map toJson() => _$NERoomKitServerConfigToJson(this);
}

///
/// G2 白板 服务器配置
///
@JsonSerializable(
  includeIfNull: false,
)
class NEWhiteboardServerConfig {
  String? webServer;
  String? roomServer;
  String? sdkLogNosServer;
  String? dataReportServer;
  String? directNosServer;
  String? mediaUploadServer;
  String? docTransServer;
  String? fontDownloadServer;

  NEWhiteboardServerConfig();

  factory NEWhiteboardServerConfig.fromJson(Map map) {
    return _$NEWhiteboardServerConfigFromJson(map.cast());
  }

  Map toJson() => _$NEWhiteboardServerConfigToJson(this);
}
